==> rcppbugs_0.0.2.tar.gz: rcppbugs/src/cppbugs/cppbugs/mcmc.rng.hpp <==
///////////////////////////////////////////////////////////////////////////
// Copyright (C) 2011 Whit Armstrong                                     //
//                                                                       //
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the GNU General Public License as published by  //
// the Free Software Foundation, either version 3 of the License, or     //
// (at your option) any later version.                                   //
//                                                                       //
// This program is distributed in the hope that it will be useful,       //
// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
// GNU General Public License for more details.                          //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program.  If not, see <http://www.gnu.org/licenses/>. //
///////////////////////////////////////////////////////////////////////////

#ifndef MCMC_RNG_HPP
#define MCMC_RNG_HPP

#include <boost/random.hpp>

namespace cppbugs {

  class RngBase {
  public:
    RngBase() {}
    virtual double normal() = 0;
    virtual double uniform() = 0;
    //virtual int poisson(n) = 0;
    // etc...
  };

  template<typename T>
  class SpecializedRng : public RngBase {
    T generator_;
    boost::normal_distribution<double> normal_rng_dist_;
    boost::uniform_real<double> uniform_rng_dist_;
    boost::variate_generator<T&, boost::normal_distribution<double> > normal_rng_;
    boost::variate_generator<T&, boost::uniform_real<double> > uniform_rng_;
  public:
    SpecializedRng(): RngBase(),
                      normal_rng_dist_(0, 1), uniform_rng_dist_(0, 1),
                      normal_rng_(generator_, normal_rng_dist_),
                      uniform_rng_(generator_, uniform_rng_dist_) {}
    double normal() { return normal_rng_(); }
    double uniform() { return uniform_rng_(); }
  };

} // namespace cppbugs
#endif // MCMC_RNG_HPP

==> rcppbugs_0.0.8.tar.gz: rcppbugs/src/cppbugs/cppbugs/mcmc.rng.hpp <==
///////////////////////////////////////////////////////////////////////////
// Copyright (C) 2011 Whit Armstrong                                     //
//                                                                       //
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the GNU General Public License as published by  //
// the Free Software Foundation, either version 3 of the License, or     //
// (at your option) any later version.                                   //
//                                                                       //
// This program is distributed in the hope that it will be useful,       //
// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
// GNU General Public License for more details.                          //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program.  If not, see <http://www.gnu.org/licenses/>. //
///////////////////////////////////////////////////////////////////////////

#ifndef MCMC_RNG_HPP
#define MCMC_RNG_HPP

#include <boost/random.hpp>
#include <cppbugs/mcmc.rng.base.hpp>

namespace cppbugs {

  template<typename T>
  class SpecializedRng : public RngBase {
    T generator_;
    boost::normal_distribution<double> normal_rng_dist_;
    boost::uniform_real<double> uniform_rng_dist_;
    boost::variate_generator<T&, boost::normal_distribution<double> > normal_rng_;
    boost::variate_generator<T&, boost::uniform_real<double> > uniform_rng_;
  public:
    SpecializedRng(): RngBase(),
                      normal_rng_dist_(0, 1), uniform_rng_dist_(0, 1),
                      normal_rng_(generator_, normal_rng_dist_),
                      uniform_rng_(generator_, uniform_rng_dist_) {}
    double normal() { return normal_rng_(); }
    double uniform() { return uniform_rng_(); }
  };

} // namespace cppbugs
#endif // MCMC_RNG_HPP
